package com.fjhx.applet.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fjhx.base.BaseEntity;
import com.fjhx.base.BaseService;
import com.fjhx.entity.stock.StockInoutbill;

import java.util.List;
import java.util.Map;

public interface FabricStatisticsService extends BaseService<BaseEntity> {

    Map<String, Object> selectFabricDetails();

    List<Map<String, Object>> selectFabricTypeDetails(Map<String, Object> condition);

    Map<String, Object> selectFabricWDetails(Map<String, Object> condition);

    List<Map<String, Object>> selectFabricWTypeDetails(Map<String, Object> condition);

    List<Map<String, Object>> selectFabricEWDetails(Map<String, String> condition);

    Map<String, Object> selectFabricStatistics(Map<String, Object> condition);

    Map<String, Object> selectFabricEW(Map<String, Object> condition);

    Map<String, Object> selectFabricW(Map<String, Object> condition);

    List<Map<String, Object>> flowNum(Map<String, String> condition);

    Page<Map<String, Object>> flowPage(Map<String, String> condition);

    Integer getApproveType(Map<String, String> condition);

}
